==> aqemu-0.7.1.tar.bz2: aqemu-0.7.1/HDD_Image_Info.cpp <==
/****************************************************************************
**
** Copyright (C) 2009 Andrey Rijov <ANDron142@yandex.ru>
**
** This file is part of AQEMU.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor,
** Boston, MA  02110-1301, USA.
**
****************************************************************************/

#include <QFile>
#include <QSettings>

#include "Utils.h"
#include "HDD_Image_Info.h"
/*
HDD_Image_Info::HDD_Image_Info( QObject* parent )
	: QObject( parent )
{
}

HDD_Image_Info::~HDD_Image_Info()
{
}*/

VM::Disk_Info HDD_Image_Info::Get_Disk_Info() const
{
	return Info;
}

QList<VM_Snapshot> HDD_Image_Info::Get_Snapshots() const
{
}

void HDD_Image_Info::Update_Disk_Info( const QString &path )
{
	Info.Image_File_Name = path;
	
	if( Info.Image_File_Name.isEmpty() ||
		QFile::exists(Info.Image_File_Name) == false )
	{
		AQError( "void QEMU_IMG_Thread::run()",
				 "Image \"" + Info.Image_File_Name + "\" Not Exists!" );
		return;
	}
	else
	{
		QStringList args;
		args << "info" << Info.Image_File_Name;
		
		QEMU_IMG_Proc = new QProcess();
		QSettings settings;
		QEMU_IMG_Proc->start( settings.value("QEMU_IMG_Path", "qemu-img").toString(), args );
		
		connect( QEMU_IMG_Proc, SIGNAL(finished(int, QProcess::ExitStatus)),
				 this, SLOT(Parse_Info(int, QProcess::ExitStatus)), Qt::DirectConnection );
		
		connect( QEMU_IMG_Proc, SIGNAL(error(QProcess::ProcessError)),
				 this, SLOT(Clear_Info()), Qt::DirectConnection );
	}
}

void HDD_Image_Info::Clear_Info()
{
	AQWarning( "void HDD_Image_Info::Clear_Info()",
			   "HDD Info Not Read!" );
	
	VM_HDD tmp_hdd;
	Info.Virtual_Size = tmp_hdd.String_to_Device_Size( "0 G" );
	Info.Disk_Size = tmp_hdd.String_to_Device_Size( "0 G" );
	Info.Cluster_Size = 0;
	
	emit Completed();
}

void HDD_Image_Info::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )
{
	AQWarning( "void HDD_Image_Info::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
			   "Starting Parsing" );
	
	QByteArray info_str_ba = QEMU_IMG_Proc->readAll();
	
	QString info_str = QString( info_str_ba ); // Create QString
	
	// image:[\s]+(.+).file format:[\s]+([\w\d]+).virtual size:[\s]+([\d]+[.]*[\d]*[KMG]+).*disk size:[\s]+([\d]+[.]*[\d]*[KMG]+).cluster_size:[\s]+([\d]+).*
	QRegExp RegInfo = QRegExp( "image:[\\s]+(.+).file format:[\\s]+([\\w\\d]+).virtual size:[\\s]+([\\d]+[.]*[\\d]*[KMG]+).*disk size:[\\s]+([\\d]+[.]*[\\d]*[KMG]+).cluster_size:[\\s]+([\\d]+).*" );
	
	bool cluster = true;
	
	if( ! RegInfo.exactMatch(info_str) )
	{
		AQWarning( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
				   "QRegExp With Cluster Size Not Matched!" );
		
		RegInfo = QRegExp( "image:[\\s]+(.+).file format:[\\s]+([\\w\\d]+).virtual size:[\\s]+([\\d]+[.]*[\\d]*[KMG]+).*disk size:[\\s]+([\\d]+[.]*[\\d]*[KMG]+).*" );
		
		if( ! RegInfo.exactMatch(info_str) )
		{
			AQError( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
					 "QRegExp Without Cluster Size Not Matched!" );
			Clear_Info();
			return;
		}
		else
		{
			cluster = false;
		}
	}
	
	QStringList info_lines = RegInfo.capturedTexts();
	
	if( cluster && info_lines.count() != 6 )
	{
		AQError( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
				 "info_str.count() != 6" );
		Clear_Info();
		return;
	}
	else if( ! cluster && info_lines.count() != 5 )
	{
		AQError( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
				 "info_str.count() != 5" );
		Clear_Info();
		return;
	}
	
	if( info_lines[ 1 ] != Info.Image_File_Name )
	{
		AQWarning( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
				   "info_lines[ 1 ] != Image_File_Name" );
	}
	
	Info.Disk_Format = info_lines[ 2 ];
	VM_HDD tmp_hdd;
	Info.Virtual_Size = tmp_hdd.String_to_Device_Size( info_lines[3] );
	Info.Disk_Size = tmp_hdd.String_to_Device_Size( info_lines[4] );
	if( cluster ) Info.Cluster_Size = info_lines[ 5 ].toInt();
	else Info.Cluster_Size = 0;
	
	AQWarning( "void HDD_Image_Info::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
			   "Parsing Done" );
	
	emit Completed();
	//delete QEMU_IMG_Proc;
}

==> aqemu-0.7.3.tar.bz2: aqemu-0.7.3/HDD_Image_Info.cpp <==
/****************************************************************************
**
** Copyright (C) 2009 Andrey Rijov <ANDron142@yandex.ru>
**
** This file is part of AQEMU.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor,
** Boston, MA  02110-1301, USA.
**
****************************************************************************/

#include <QFile>
#include <QSettings>

#include "Utils.h"
#include "HDD_Image_Info.h"

VM::Disk_Info HDD_Image_Info::Get_Disk_Info() const
{
	return Info;
}

void HDD_Image_Info::Update_Disk_Info( const QString &path )
{
	Info.Image_File_Name = path;
	
	if( Info.Image_File_Name.isEmpty() ||
		QFile::exists(Info.Image_File_Name) == false )
	{
		//AQError( "void QEMU_IMG_Thread::run()",
		//		 "Image \"" + Info.Image_File_Name + "\" Not Exists!" );
		Clear_Info();
		return;
	}
	else
	{
		QStringList args;
		args << "info" << Info.Image_File_Name;
		
		QEMU_IMG_Proc = new QProcess();
		QSettings settings;
		QEMU_IMG_Proc->start( Get_Default_QEMU_IMG_Path(), args );
		
		connect( QEMU_IMG_Proc, SIGNAL(finished(int, QProcess::ExitStatus)),
				 this, SLOT(Parse_Info(int, QProcess::ExitStatus)), Qt::DirectConnection );
		
		connect( QEMU_IMG_Proc, SIGNAL(error(QProcess::ProcessError)),
				 this, SLOT(Clear_Info()), Qt::DirectConnection );
	}
}

void HDD_Image_Info::Clear_Info()
{
	AQWarning( "void HDD_Image_Info::Clear_Info()",
			   "HDD Info Not Read!" );
	
	VM_HDD tmp_hdd;
	Info.Disk_Format = "";
	Info.Virtual_Size = tmp_hdd.String_to_Device_Size( "0 G" );
	Info.Disk_Size = tmp_hdd.String_to_Device_Size( "0 G" );
	Info.Cluster_Size = 0;
	
	emit Completed();
}

void HDD_Image_Info::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )
{
	QByteArray info_str_ba = QEMU_IMG_Proc->readAll();
	
	QString info_str = QString( info_str_ba ); // Create QString
	
	// image:[\s]+(.+).file format:[\s]+([\w\d]+).virtual size:[\s]+([\d]+[.]*[\d]*[KMG]+).*disk size:[\s]+([\d]+[.]*[\d]*[KMG]+).cluster_size:[\s]+([\d]+).*
	QRegExp RegInfo = QRegExp( "image:[\\s]+(.+).file format:[\\s]+([\\w\\d]+).virtual size:[\\s]+([\\d]+[.]*[\\d]*[KMG]+).*disk size:[\\s]+([\\d]+[.]*[\\d]*[KMG]+).cluster_size:[\\s]+([\\d]+).*" );
	
	bool cluster = true;
	
	if( ! RegInfo.exactMatch(info_str) )
	{
		AQWarning( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
				   "QRegExp With Cluster Size Not Matched!" );
		
		RegInfo = QRegExp( "image:[\\s]+(.+).file format:[\\s]+([\\w\\d]+).virtual size:[\\s]+([\\d]+[.]*[\\d]*[KMG]+).*disk size:[\\s]+([\\d]+[.]*[\\d]*[KMG]+).*" );
		
		if( ! RegInfo.exactMatch(info_str) )
		{
			AQError( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
					 "QRegExp Without Cluster Size Not Matched!" );
			Clear_Info();
			return;
		}
		else
		{
			cluster = false;
		}
	}
	
	QStringList info_lines = RegInfo.capturedTexts();
	
	if( cluster && info_lines.count() != 6 )
	{
		AQError( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
				 "info_str.count() != 6" );
		Clear_Info();
		return;
	}
	else if( ! cluster && info_lines.count() != 5 )
	{
		AQError( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
				 "info_str.count() != 5" );
		Clear_Info();
		return;
	}
	
	if( info_lines[ 1 ] != Info.Image_File_Name )
	{
		AQWarning( "void QEMU_IMG_Thread::Parse_Info( int exitCode, QProcess::ExitStatus exitStatus )",
				   "info_lines[ 1 ] != Image_File_Name" );
	}
	
	Info.Disk_Format = info_lines[ 2 ];
	VM_HDD tmp_hdd;
	Info.Virtual_Size = tmp_hdd.String_to_Device_Size( info_lines[3] );
	Info.Disk_Size = tmp_hdd.String_to_Device_Size( info_lines[4] );
	if( cluster ) Info.Cluster_Size = info_lines[ 5 ].toInt();
	else Info.Cluster_Size = 0;
	
	emit Completed();
	//delete QEMU_IMG_Proc;
}
